OC.L10N.register(
    "files_sharing",
    {
    "Uploading..." : "تحميل",
    "Cancel" : "إلغاء",
    "Share" : "شارك",
    "Shared by" : "تم مشاركتها بواسطة",
    "Sharing" : "مشاركة",
    "A file or folder has been <strong>shared</strong>" : "ملف أو مجلد تم </strong>مشاركته<strong> ",
    "You shared %1$s with %2$s" : "شاركت %1$s مع %2$s",
    "You shared %1$s with group %2$s" : "أنت شاركت %1$s مع مجموعة %2$s",
    "You shared %1$s via link" : "لقد قمت بمشاركة %1$s عبر الرابط",
    "%2$s shared %1$s with you" : "%2$s شارك %1$s معك",
    "Shares" : "المشاركات",
    "This share is password-protected" : "هذه المشاركة محمية بكلمة مرور",
    "The password is wrong. Try again." : "كلمة المرور خاطئة. حاول مرة أخرى",
    "Password" : "كلمة المرور",
    "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
    "Name" : "اسم",
    "Expiration date" : "تاريخ إنتهاء الصلاحية",
    "Sorry, this link doesn’t seem to work anymore." : "عذرا، يبدو أن هذا الرابط لم يعد يعمل.",
    "Reasons might be:" : "الأسباب الممكنة :",
    "the item was removed" : "تم حذف العنصر المطلوب",
    "the link expired" : "انتهت صلاحية الرابط",
    "sharing is disabled" : "المشاركة غير مفعلة",
    "For more info, please ask the person who sent this link." : "لمزيد من المعلومات، يرجى سؤال الشخص الذي أرسل هذا الرابط",
    "Download" : "تحميل",
    "Download %s" : "تحميل %s",
    "Direct link" : "رابط مباشر",
    "Pending" : "قيد الانتظار",
    "Accept" : "قبول",
    "Declined" : "رفض"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
